泰坦尼克号 (豆瓣)
Description: 泰坦尼克号电影简介和剧情介绍,泰坦尼克号影评、图片、预告片、影讯、论坛、在线购票
Keywords: 泰坦尼克号,Titanic,泰坦尼克号影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.4豆瓣电影Top250

# 泰坦尼克号 Titanic (1997)

更新描述或海报

导演: 詹姆斯·卡梅隆
编剧: 詹姆斯·卡梅隆
主演: 莱昂纳多·迪卡普里奥 / 凯特·温丝莱特 / 比利·赞恩 / 凯西·贝茨 / 弗兰西丝·费舍 / 格劳瑞亚·斯图尔特 / 比尔·帕克斯顿 / 伯纳德·希尔 / 大卫·沃纳 / 维克多·加博 / 乔纳森·海德 / 苏茜·爱米斯 / 刘易斯·阿伯内西 / 尼古拉斯·卡斯柯恩 / 阿那托利·萨加洛维奇 / 丹尼·努齐 / 杰森·贝瑞 / 伊万·斯图尔特 / 艾恩·格拉法德 / 乔纳森·菲利普斯 / 马克·林赛·查普曼 / 理查德·格拉翰 / 保罗·布赖特威尔 / 艾瑞克·布里登 / 夏洛特·查顿 / 博纳德·福克斯 / 迈克尔·英塞恩 / 法妮·布雷特 / 马丁·贾维斯 / 罗莎琳·艾尔斯 / 罗切尔·罗斯 / 乔纳森·伊万斯-琼斯 / 西蒙·克雷恩 / 爱德华德·弗莱彻 / 斯科特·安德森 / 马丁·伊斯特 / 克雷格·凯利 / 格雷戈里·库克 / 利亚姆·图伊 / 詹姆斯·兰开斯特 / 艾尔莎·瑞雯 / 卢·帕尔特 / 泰瑞·佛瑞斯塔 / 凯文·德·拉·诺伊
类型: 剧情 / 爱情 / 灾难
制片国家/地区: 美国 / 墨西哥 / 澳大利亚 / 加拿大
语言: 英语 / 意大利语 / 德语 / 俄语
上映日期: 1998-04-03(中国大陆) / 1997-11-01(东京电影节) / 1997-12-19(美国)
片长: 194分钟 / 227分钟(白星版)
又名: 铁达尼号(港/台)
IMDb: tt0120338
豆瓣评分
引用
9.4
2014484人评价
5星
76.1%
4星
20.7%
3星
3.0%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
9.3
6人评价
好于 99% 爱情片
好于 99% 灾难片
我看过这部电影 2020-07-12 修改
我的评价:
推荐

## 泰坦尼克号的剧情简介 · · · · · ·

1912年4月10日，号称 “世界工业史上的奇迹”的豪华客轮泰坦尼克号开始了自己的处女航，从英国的南安普顿出发驶往美国纽约。富家少女罗丝（凯特•温丝莱特）与母亲及未婚夫卡尔坐上了头等舱；另一边，放荡不羁的少年画家杰克（莱昂纳多·迪卡普里奥）也在码头的一场赌博中赢得了下等舱的船票。
罗丝厌倦了上流社会虚伪的生活，不愿嫁给卡尔，打算投海自尽，被杰克救起。很快，美丽活泼的罗丝与英俊开朗的杰克相爱，杰克带罗丝参加下等舱的舞会、为她画像，二人的感情逐渐升温。
1912年4月14日，星期天晚上，一个风平浪静的夜晚。泰坦尼克号撞上了冰山，“永不沉没的”泰坦尼克号面临沉船的命运，罗丝和杰克刚萌芽的爱情也将经历生死的考验。 ©豆瓣

## 泰坦尼克号的演职员 · · · · · · ( 全部 152 )

- 詹姆斯·卡梅隆 导演
- 莱昂纳多·迪卡普里奥 饰 杰克 Jack Dawson
- 凯特·温丝莱特 饰 罗丝 Rose DeWitt Bukater
- 比利·赞恩 饰 卡尔 Caledon 'Cal' Hockley
- 凯西·贝茨 饰 莫莉 Molly Brown
- 弗兰西丝·费舍 饰 鲁丝 Ruth Dewitt Bukater

## 泰坦尼克号的视频和图片 · · · · · · ( 预告片9 | 视频评论1 · 添加 | 图片1390 · 添加 )

## 泰坦尼克号的获奖情况 · · · · · · ( 全部 )

- 第70届奥斯卡金像奖
- 最佳影片
- 詹姆斯·卡梅隆 / 乔恩·兰道

- 第55届金球奖
- 电影类 最佳剧情片

- 第21届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  恋恋笔记本

  爱在黎明破晓前

  重庆森林

  剪刀手爱德华

  傲慢与偏见

  怦然心动

  乱世佳人

  大话西游之大圣娶亲

  天使爱美丽

我要写短评

## 泰坦尼克号的短评 · · · · · · ( 全部 344392 条 )

热门 / 最新 / 好友

### 12775 有用 个篱 看过 2006-11-16 15:23:40

那对对死无所畏惧的老夫妇，那个不为外界干扰的乐队，那个为生而做一次假父亲的男人，那个为爱人吹响口哨的女人。都是为了一种心灵上的执着。

### 13874 有用 影志 看过 2006-02-04 06:19:25

“我甚至连一张他的画像都没有，但他永远活在我心中。” 要敢说，这是我一直深爱的电影。

### 5556 有用 南国玫瑰 看过 2008-01-17 07:37:12

若干年后，2010年12月27日凌晨一点半，我不知道还有谁醒着没睡，还有谁和我一样，刚重温过这片子，或是刚刚打开准备重温。我又哭得很惨，这是毫无疑问的。我想，之所以不情愿活着，是因为没有那个如此相爱想要厮守的人；不情愿死去，是因为没有一个人如此爱我，值得我为他去死。

### 10330 有用 沉歌 看过 2007-10-14 15:40:11

爱你原本只是一瞬，却不知在时间的洪流中成了永恒。

### 6519 有用 Doublebitch 看过 2008-11-24 22:15:43

将永远是我在电影院所看过次数最多、最感动、也是最好的电影

> 更多短评 344392条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-03-11 22:42:22

死亡，不会让爱情变得好伟大。让爱情变得伟大只有是它本身是伟大所以才伟大。

我要写影评

## 泰坦尼克号的影评 · · · · · · ( 全部 4728 条 )

热门 / 最新 / 好友
waffler22 2009-02-24 09:59:05

## 十年一觉电影梦——泰坦尼克号十年记

□左儿(http://www.douban.com/people/lefter/) 题记 一个特殊的时代造就了［泰坦尼克］。今年11月，是［泰坦尼克］十周年，我们郑重其事回头打量，发现它在商业和文艺领域的巨大成功绝非个案这么简单。尽管就连当时华尔街分析人士也认为，若这部耗资两亿的电影成功，势必把好... (展开)
3738 203 518回应 收起
Lethe。 2007-12-08 22:28:22

## Nearer My God To Thee。

更近我主。 在死亡来临的时刻。 上帝擦去他们所有的眼泪 死亡不再有 也不再有悲伤和生死离别 不再有痛苦 因为往事已逝。 当我看见逸夫楼的公告板上写着下午放映《泰坦尼克号》时，抑制不住内心的冲动再次坐到了放映厅里——这是我第三次观看此片，也是第一次和这么多人一起看电... (展开)
3974 129 255回应 收起
沉静如海 2009-12-30 03:17:36

## 一个被忽略的小人，卡尔

夜深如海，我静静的躺在床上看着泰坦尼克号，不知道是第几次看了，似乎这已经变成了一个习惯，在我需要流泪的时候。 这一次，我被一个叫卡尔的小人感动了。一直似乎都将聚光灯打在主角的身上，杰克和罗丝的爱情毫无疑问的荡气回肠，每一次都恨卡尔捣乱自私，将一次次逃生的机会... (展开)
2703 141 598回应 收起
南十字 2007-11-03 15:56:41

## 十年过后，犹记泰坦尼克

不知不觉间，距离1997年11月1日已经过了整十年，换个说法：十年（又好几天）前，《泰坦尼克号》首映。 十年前只能用猫吱呀着拨号上网，十年后已经没人能忍受512K以下的带宽；十年前哈利波特第一部刚刚出版，十年后J.K.罗琳为眼镜魔法少年的故事画上了句号；十年前的... (展开)
739 54 204回应 收起
欧阳杨 2010-09-28 11:27:26

## 严重剧透！

泰坦尼克号叙述了柯布大叔年轻的时候化名杰克，潜入美女露丝的梦中，离间露丝与其龙套未婚夫的关系的经典科幻悬疑谍战大片！ 作为一个年轻人，年轻的柯布显然在造梦这种高技术含量的工作上欠点火候。 果然，计划进行到一半，柯布的梦境要崩溃了！丫造出来的大船装到了冰山上！... (展开)
762 287 139回应 收起
youheisme 2006-04-12 22:17:32

## He saved me,in every way that a person can be saved.

He saved me,in every way that a person can be saved.这是老露丝说的一句话。很让人回味。 杰克不仅救了她的命，而且还从一个人生活的各个方面拯救了，让她找到了生命的真谛。因为杰克给了露丝活下去的勇气和信念。他虽然离开了，可是在她心里他依然守候，依然陪伴。正... (展开)
452 24 40回应 收起
叔菜 2009-07-22 16:51:56

## 为Titanic平反

看到不少所谓最杰出XX部电影的榜单，总是刻意把Titanic排在外面，当时的技术、编导、音效、演员无不是超一流，就是因为当年票房太高，所以引起了不少清高人士的反感。 好电影，为什么不能是票房最高的？为什么不能是最多人喜欢的？ Titanic之后，还有哪部电影有这么大影响力... (展开)
356 42 98回应 收起
宁宁 2010-10-07 18:18:01

## Titanic：Love is an old story

时至今日来谈论《Titanic》，似乎在讲述一个古老的故事，像是在说：很久很久以前······ 虽然《Titanic》已了然无新意了，不过每一次重温，都能给人不一样的感受。 以前，我一直不理解Jack ，总觉得他是个爱浪漫的男孩子，有自由的价值观，喜欢过无拘无束的生活，“To m... (展开)
317 6 20回应 收起
品茗听雨轩 2017-07-28 15:49:18

## 重温经典爱情剧的经典对白

1、只要你装得很有钱的样子他们就会跟你套近乎。 ——《泰坦尼克号》 　　2、“Never let go!Promise me!——”——《泰坦尼克号》 　　3、赢得船票，是我一生最幸运的事，让我可认识你，认识你真荣幸，万分荣幸， 你一定要帮我，答应我活下去，答应我，你不会放弃，无论发生... (展开)
275 8 6回应 收起

> 更多影评 4728篇

添加新讨论

## 讨论区 · · · · · ·

最长版本多少分钟？ | 来自豆友7225225018 | 83 回应 | 2022-11-24 02:39:45
哪里有白星版可以看么 | 来自52星 | 74 回应 | 2022-11-21 16:09:08
爱情很美好，故事很感人，但还是无法摆脱小3的事实。 | 来自重灵儿 | 260 回应 | 2022-11-20 23:05:48
放在当今社会，我敢保证100个女人100个选卡尔 | 来自prenstrong | 115 回应 | 2022-11-20 23:03:49
导演卡梅隆之后是不是就没作品了？ | 来自香水瓶 | 27 回应 | 2022-11-20 01:23:12

> 去这部影片的讨论区（全部1473条）

## 关于《泰坦尼克号》的问题 · · · · · · ( 全部24个 )

- 給1-2星的人，你們5星電影應該是transformer1-4吧？ 18人回答
- IMDB 才7.7 分，不 觉 得 很 低 吗 ？ 22人回答

> 全部24个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 芒果TV VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 【内牛满面】 (影志)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)
- 100部爱情电影 经典的回味 (isay)

## 谁在看这部电影 · · · · · ·

- Sky
  1分钟前 想看
- 清奈
  1分钟前 看过
- momo
  1分钟前 看过

3716819人看过 / 247441人想看

订阅泰坦尼克号的评论:
feed: rss 2.0